package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0D```````````(`/@`!````@'`@``````!``````````("L````
M`````````$``.``+`$``'0`<``8````$````0`````````!``"```````$``
M(```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"(```````J`(@```````5`````````!4``````````0`````````!````
M!``````````````````@`````````"```````'1@````````=&``````````
M$`````````$````%````@&````````"`<"```````(!P(```````,$8`````
M```P1@`````````0`````````0````8```"PI@```````+#&(```````L,8@
M```````8`@```````!@"`````````!`````````!````!@```,BH````````
MR-@@``````#(V"```````!@"````````J0(`````````$`````````(````&
M````X*8```````#@QB```````.#&(```````X`$```````#@`0````````@`
M````````4N5T9`0```"PI@```````+#&(```````L,8@```````8`@``````
M`%`)`````````0````````!0Y71D!````$A;````````2%L@``````!(6R``
M`````-P`````````W``````````$`````````%'E=&0&````````````````
M````````````````````````````````````````````````````!`````0`
M``#``@```````,`"(```````P`(@``````!(`````````$@`````````!```
M```````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````!`````$```!&<F5E
M0E-$`"%=%0`(````!`````0```!&<F5E0E-$```````(````!`````(```!&
M<F5E0E-$```````````````````````````````````````-````$@``````
M```````````````````Z````(`````````````````````````!6````%@``
M``````````````````````!Y````$@````````````````````````"L````
M$@````````````````````````"S````$@````````````````````````"[
M````$@````````````````````````#$````$@``````````````````````
M``#+````$@````````````````````````#2````$@``````````````````
M```````!`0``$@`````````````````````````)`0``$@``````````````
M```````````0`0``$@`````````````````````````7`0``$@``````````
M```````````````>`0``$@`````````````````````````E`0``$@``````
M```````````````````L`0``$@`````````````````````````Q`0``$@``
M```````````````````````X`0``$@````````````````````````!``0``
M$@````````````````````````!5`0``$@````````````````````````!I
M`0``$@````````````````````````"=`0``$@``````````````````````
M``"F`0``$@````````````````````````#&`0``$@``````````````````
M``````#-`0``$@````````````````````````#U`0``$@``````````````
M``````````#[`0``$@`````````````````````````!`@``$@``````````
M```````````````)`@``$@`````````````````````````1`@``$@``````
M```````````````````6`@``$@`````````````````````````<`@``$@``
M```````````````````````A`@``$@`````````````````````````R`@``
M$@`````````````````````````Z`@``$@````````````````````````!"
M`@``$@````````````````````````!)`@``$@``````````````````````
M``!2`@``$@````````````````````````!N`@``$@``````````````````
M``````!^`@``$@````````````````````````",`@``$@``````````````
M``````````"3`@``$@````````````````````````"B`@``$@``````````
M``````````````"N`@``$@````````````````````````"Z`@``$@``````
M``````````````````#/`@``$@`````````````````````````"`P``$@``
M```````````````````````>`P``$@`````````````````````````I`P``
M$@`````````````````````````X`P``$@````````````````````````!5
M`P``$@````````````````````````!@`P``$@``````````````````````
M``!I`P``$@````````````````````````!W`P``$@``````````````````
M``````"!`P``$@````````````````````````"/`P``$@``````````````
M``````````"^`P``$@````````````````````````!.````$@`.`"!Q(```
M````+0````````!I````$@```!"S(`````````````````":````$0`:`"#;
M(```````0`````````#H`0``$@`.`/"$(```````30H```````"I`P``$@`.
M`."9(```````_0`````````T````$@`0`,BR(``````````````````(````
M$@`.`)"5(```````D@,```````#C````$@`.`!!R(```````L0````````#T
M````$@`.`-!R(```````.P(```````!P`0``$@`.`'!X(```````&@H`````
M``"K`0``$@`.`."#(```````'@````````#6`0``$@`.``"$(```````Z```
M``````#>`@``$@```."U(`````````````````#O`@``$@```/"U(```````
M```````````1`P``$0`:`'#;(````````0`````````!````$@`.`(!P(```
M````,0````````"$````$@`.`%!Q(```````L0````````!=`0``$@`.`&!W
M(````````@$```````!]`0``$@`.`)""(```````KP````````"3`0``$0`:
M`&#;(```````"``````````F`@``$@`.`$"/(```````]0````````!+`P``
M$0`8`-#8(```````"`````````"@`P``$@`.`)"9(```````3`````````"T
M`P``$@`.`!"Q(```````<@$````````N````$@`/`+RR(```````````````
M``!(`0``$@`.`#!W(```````*0````````!8`@``$@`.`,"1(```````P0,`
M```````;````$0`8`,C8(```````"``````````F````$0`:`.#:(```````
M"`````````"+`0``$@`.`$"#(```````F0````````````(``0`!``$``P`#
M``,``P`#``,``P`#``,``P`#``,`!``#``,``P`#``,``P`#``,``P`$``,`
M`P`#``,``P`#``,``P`$``,``P`#``$``0`#``$``0`!``$``0`%``$``0`!
M``$``0`!``$``0`!``,``0`!``,``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`#``$``0`!``$``0`!``$``0`!``$````!``$`Q0,``"`````0
M`````0`#`-H#```@`````````+`H>@<```4`T0,```````"P*'H'```#`-$#
M```0````M2AZ!P``!`#D`P``$````+<H>@<```(`[0,`````````````!P``
M`#L````(````&@````((,``!``P("``0!`($``@```0`B```$`"($(``````
M"`````%@``"```""P(0`@$@!``Y!`!0!#0H`$8L$``@[````/````$````!!
M````2@```%,```!6````P^4_+'KP2FL@8F0'SMY'+4/ZUX?KT^\.:G^:?"[%
MF[8@_^0.HN#[27ZIG)OZH6Q@AOF<@<C5LG$+BA!7,F+;[>"G`@IFK\QFL@&+
M;^85`X-NQ=\?B`=PTQ2,)<QK&IY0N(WQ#N)'Q@'59-1\O%!VGJ;=HVN93\.;
M60```%D````9````3@````````!6````'P```"4````Z````2`````````!3
M````0@```````````````````````````````````%```````````````%$`
M```R````/0```$\````\````2@```$<````K`````````!(```!4````)@``
M``L````I````/P```!P`````````'0```$``````````&@````\`````````
M30```"(````V````-P```"T```!8`````````%<```!!````3````"\````3
M````&````"P````A`````````#$````N`````````!X`````````-```````
M``!2```````````````^``````````,`````````&P```#@`````````1@``
M````````````$````$L`````````,P```#D```!$````20``````````````
M50````````````````````````````````````````````````````@`````
M````````````````````````````````````````````````````$0``````
M````````%`````4```````````````H`````````````````````````````
M```````5```````````````````````````````.```````````````D````
M``````$````````````````````H````)P``````````````!P``````````
M`````````#4`````````(``````````"````#0```````````````````",`
M```[````!`````8`````````0P````D````````````````````,````,```
M``````````````````````!%````%@`````````7`````````"H`````````
M`%]S=&%R=`!M86EN`%]?;&EB8U]S=&%R=#$`7U]P<F]G;F%M90!E;G9I<F]N
M`%]I;FET`%]F:6YI`%]*=E]296=I<W1E<D-L87-S97,`>'-?:6YI=`!03%]C
M=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?<W1A8VM?8VAK7V=U87)D`&=E='!I9`!S
M<')I;G1F`')E861L:6YK`&UA;&QO8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I
M;`!P87)?8W5R<F5N=%]E>&5C`'!A<E]F:6YD<')O9P!S=')N8VUP`'-T<F-H
M<@!S=')D=7``<W1R=&]K`'-T<F-M<`!S=')L96X`<W1A=`!A8V-E<W,`<F5A
M;&QO8P!M96UM;W9E`'!A<E]B87-E;F%M90!S=')R8VAR`'!A<E]D:7)N86UE
M`'-T<F-P>0!P87)?:6YI=%]E;G8`<&%R7V5N=E]C;&5A;@!P87)?9&EE`%]?
M<W1D97)R<`!V9G!R:6YT9@!E>&ET`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`&=E='5I9`!G971P=W5I9`!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`;'-T870`;6MD:7(`7U]E<G)O<@!F<')I;G1F`&]P96X`;'-E96L`
M<F5A9`!F<F5E`'!A<E]C;&5A;G5P`&]P96YD:7(`<F5A9&1I<@!U;FQI;FL`
M8VQO<V5D:7(`<FUD:7(`6%-?26YT97)N86QS7U!!4E]"3T]4`%!E<FQ?9W9?
M9F5T8VAP=@!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!0
M97)L7V=E=%]S=@!097)L7VUG7W-E=`!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N
M;&]C:P!P=&AR96%D7V%T9F]R:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!097)L7W-A9F5S>7-M86QL;V,`;7E?<&%R7W!L`'!E
M<FQ?<&%R<V4`<&5R;%]R=6X`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R
M;%]S>7-?=&5R;0!097)L7VYE=UA37V9L86=S`'-H85]I;FET`'-H85]U<&1A
M=&4`<VAA7V9I;F%L`&UE;7-E=`!L:6)T:'(N<V\N,P!&0E-$7S$N,`!L:6)C
M+G-O+C<`1D)31%\Q+C4`1D)31%\Q+C<`+W5S<B]L;V-A;"]L:6(O<&5R;#4O
M-2XS."]M86-H+T-/4D4`;&EB<&5R;"YS;RXU+C,X`&QI8F1L+G-O+C$`;&EB
M;2YS;RXU`&QI8F-R>7!T+G-O+C4`;&EB=71I;"YS;RXY````P,@@```````2
M`````P``````````````(-L@```````%````/0``````````````<-L@````
M```%````20``````````````8-L@```````%````3@```````````````-D@
M```````'`````0``````````````"-D@```````'`````@``````````````
M$-D@```````'````/```````````````&-D@```````'````!```````````
M````(-D@```````'````!0``````````````*-D@```````'````!@``````
M````````,-D@```````'````!P``````````````.-D@```````'````"```
M````````````0-D@```````'````"0``````````````2-D@```````'````
M"@``````````````4-D@```````'````"P``````````````6-D@```````'
M````#```````````````8-D@```````'````#0``````````````:-D@````
M```'````#@``````````````<-D@```````'````#P``````````````>-D@
M```````'````$```````````````@-D@```````'````$0``````````````
MB-D@```````'````$@``````````````D-D@```````'````$P``````````
M````F-D@```````'````%```````````````H-D@```````'````%0``````
M````````J-D@```````'````%@``````````````L-D@```````'````%P``
M````````````N-D@```````'````&```````````````P-D@```````'````
M&0``````````````R-D@```````'````&@``````````````T-D@```````'
M````&P``````````````V-D@```````'````'```````````````X-D@````
M```'````'0``````````````Z-D@```````'````'@``````````````\-D@
M```````'````'P``````````````^-D@```````'````(```````````````
M`-H@```````'````(0``````````````"-H@```````'````(@``````````
M````$-H@```````'````(P``````````````&-H@```````'````)```````
M````````(-H@```````'````)0``````````````*-H@```````'````)@``
M````````````,-H@```````'````)P``````````````.-H@```````'````
M*```````````````0-H@```````'````*0``````````````2-H@```````'
M````*@``````````````4-H@```````'````*P``````````````6-H@````
M```'````+```````````````8-H@```````'````+0``````````````:-H@
M```````'````+@``````````````<-H@```````'````+P``````````````
M>-H@```````'````1P``````````````@-H@```````'````2```````````
M````B-H@```````'````,```````````````D-H@```````'````,0``````
M````````F-H@```````'````,@``````````````H-H@```````'````,P``
M````````````J-H@```````'````-```````````````L-H@```````'````
M-0``````````````N-H@```````'````-@``````````````P-H@```````'
M````-P``````````````R-H@```````'````.```````````````T-H@````
M```'````.0``````````````V-H@```````'````.@``````````````````
M``````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`4$%27U!23T=.04U%
M`"]T;7`O`%5315).04U%`"XN`#``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`E
M<R5S=&5M<"TE=2TE=25S`"TM`%1%35``55-%4@!365-414T`,0!005)?1TQ/
M0D%,7U1-4$1)4@!R96%D(&9A:6QE9`!005)?0T%#2$4`5$5-4$1)4@``4$%2
M7U1%35``4$523$Q)0@!005)?24Y)5$E!3$E:140`)7,Z('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@
M<F5T<GD@>6]U<B!O<&5R871I;VXI"@!S:&]R="!R96%D`"5S)7-C86-H92TE
M<R5S`"5S+R5S`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&9I;&4`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7T-,14%.`#$N,#8S`&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'
M24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?
M<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P
M.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R
M7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@
M*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.
M3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@
M*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B
M=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY
M("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R
M;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@
M+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO
M9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I
M;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN
M+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD
M(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M
M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A
M<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L
M("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O
M;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S
M(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\
M(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-
M04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U
M=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B
M7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA
M<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD
M72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L
M(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F
M9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S
M=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?
M;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E
M('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO
M9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H
M)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I
M;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET[
M"GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_
M"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]
M?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ
M<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=
M.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B
M1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N
M=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T
M;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]
M*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I
M;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K
M("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N
M86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?
M<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E
M="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z
M:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY
M("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H
M95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S
M:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U
M9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*
M)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP
M;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I
M+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@
M:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`+W!R;V,O8W5R<')O8R]F:6QE`%!%4DPU3$E"`%1-4$1)4@!L<V5E:R!F
M86EL960`)7,E<R5S`%!!4E]#3$5!3@!0051(`'!A<FP`+P`Z`%!!4E]'3$]"
M04Q?5$5-4`!P87(M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`&`!005(Z.E!A8VME<CHZ5D52
M4TE/3@!015),24\`<&5R;`!005)?4U!!5TY%1`!005)?1TQ/0D%,7T1%0E5'
M`"YP87(`)3`R>`!005)?1$5"54<`56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`4$523#5/4%0`5$U0`"5S)7,E<R5S`"]P<F]C+R5I+R5S`"X`
M3$1?3$E"4D%265]0051(`"5S)7-T96UP+25U)7,``"XO<&5R;'AS:2YC````
M```7'"```````,59(```````8!L@```````E&R```````,9:(```````````
M````````0T%#2$4```$;`SO<````&@```#@5``#X````>!4``!@!``"H%0``
M.`$``-@5``!8`0``"!8``'@!``#(%@``H`$``(@7``#(`0``R!D``/@!``#H
M&P``*`(``!@<``!(`@``*!T``'@"``!()P``I`(``/@G``#,`@``F"@``.@"
M``"X*```$`,``*@I```X`P``^#,``'`#``#X-```H`,``'@V``#8`P``2#H`
M``@$``#H/0``.`0``$@^``!@!```F#X``(`$``"8/P``K`0``,A5``#<!```
M2%<```@%````````%``````````!>E(``7@0`1L,!PB0`0``'````!P````X
M%```,0`````'$$$."$.&`@T&```````<````/````%@4```L`````$$.$(8"
M0PT&0H,#90P'"!P```!<````:!0``"0`````2PX0A@)##09)#`<(Q@``'```
M`'P```!X%```+0````!!#A"&`D,-!F0,!P@````D````G````(@4``"Q````
M`$$.$(8"0PT&2H,$C@,"G0P'"$$,!A``)````,0````@%0``L0````!!#A"&
M`D,-!DJ#!(X#`IT,!PA!#`80`"P```#L````N!4``#L"````00X0A@)##090
M@P>,!HT%C@2/`P+P#`<(00P&$````"P````<`0``R!<``"`"````00X0A@)#
M#09-@P>,!HT%C@2/`P/M`0P'"$$,!A```!P```!,`0``N!D``"D`````00X0
MA@)##09"@P->#`<(+````&P!``#(&0```@$```!!#A"&`D,-!DJ#!(X#`E8,
M!PA%#`80`I,,!PA!#`80*````)P!``"H&@``&@H```!!#A"&`D,-!DJ#!XP&
MC06.!(\#`P<*#`<(```D````R`$``)PD``"O`````$$.$(8"0PT&1X,&C`6.
M!(\#`J,,!P@`&````/`!```D)0``F0````!!#A"&`D,-!@```"0````,`@``
MJ"4``!X`````00X0A@)##095#`<(00P&$$,,!P@````D````-`(``*`E``#H
M`````$$.$(8"0PT&1X,&C`6.!(\#`M@,!P@`-````%P"``!H)@``30H```!!
M#A"&`D,-!E"#!XP&C06.!(\#`L\,!PA%#`80`WP$#`<(00P&$``L````E`(`
M`(`P``#U`````$$.$(8"0PT&1X,&C`6.!(\#`MP,!PA!#`802PP'"``T````
MQ`(``%`Q``!]`0```$$.$(8"0PT&4(,'C`:-!8X$CP,#-0$,!PA!#`80:0P'
M"$4,!A```"P```#\`@``F#(``,$#````00X0A@)##090@P>,!HT%C@2/`P-N
M`PP'"$$,!A```"P````L`P``.#8``)(#````00X0A@)##09-@P>,!HT%C@2/
M`P-Q`PP'"$$,!A```"0```!<`P``J#D``%0`````00X0A@)##09#@P2.`P)(
M#`<(```````<````A`,``.`Y``!,`````$$.$(8"0PT&`D<,!P@``"@```"D
M`P``$#H``/T`````00X0A@)##09*@P>,!HT%C@2/`P+N#`<(````+````-`#
M``#D.@``(18```!!#A"&`D,-!E"#!XP&C06.!(\#`P<6#`<(00P&$```*```
M```$``#D4```<@$```!!#A"&`D,-!DJ#!XP&C06.!(\#`U\!#`<(```<````
M+`0``#A2```L`````$$.$(8"0PT&0H,#90P'"`````````````````````!5
M2(GE2(GQ2(G^2(/&"$B)^DB#PA!(8P>)QTC!X`-(`<))N)"5(```````Z$!"
M``#,S,S,S,S,S,S,S,S,S,S,54B)Y5-0N\C&(``/'T0``$B+`TB-2`%(@_D"
M<@C_T$B#PPCKZTB#Q`A;7<,/'T``N`````!(A<!T&55(B>5(@SW*50```%UT
M"K_0QB``Z>U!``##S,S,S,S,S,S,S,S,54B)Y4B+!957``!D2(L,)0````!(
MBSP!OI`:(`"Z$+,@`+D`6R``7>G300``#Q\`54B)Y4%64TB!["`(``!(BP6[
M:0``2(E%Z.C"00``,=M(C;W@^___OM-:(`"Y$AP@`(G",<#HMD$``(7`>%)(
MC;W@^___2(VUT/?__[H`!```Z*I!``!)B<9%A?9X,$&-1@%(8_CHID$``$B%
MP'0?2(G#18GV2(VUT/?__TB)QTR)\NB900``0L8$,P#K`C';2(L%.6D``$@[
M1>AU#TB)V$B!Q"`(``!;05Y=P^A_00``9F9F9F9F+@\?A```````54B)Y4%6
M4TB!["`(``!(BP7[:```2(E%Z.@"00``,=M(C;W@^___OM-:(`"Y$AP@`(G"
M,<#H]D```(7`>%)(C;W@^___2(VUT/?__[H`!```Z.I```!)B<9%A?9X,$&-
M1@%(8_CHYD```$B%P'0?2(G#18GV2(VUT/?__TB)QTR)\NC90```0L8$,P#K
M`C';2(L%>6@``$@[1>AU#TB)V$B!Q"`(``!;05Y=P^B_0```9F9F9F9F+@\?
MA```````54B)Y4%7059!54%44TB![/@$``!)B?1(B?M(BP4O:```2(E%T$R+
M/>1G``!-A?\/A'P```!,B:7H^O__N&D;(`!%,>1(N0`````!````9I`/MA"%
MTG0-@_H]=`A(_\!)`<SK[$V++TV%[71*2<'\($F#QPA%,?;K$P\?@`````!-
MBR])@\<(387M="V^:1L@`$R)[TR)XN@D0```A<!UX$.`?"4`/7783XTT+$G_
MQNL(13'VZPI%,?9,BZ7H^O__2(G?OB\```#H`T```$B%P'0SOZP:(`!(B=[H
M80$``$B+!6IG``!(.T70#X5&`0``2(G82('$^`0``%M!7$%=05Y!7UW#3(GG
MZ-,_``"^]ED@`$B)Q^C6/P``2(7`=+-)B<5,C;W0^___ZQD/'T0``+[V62``
M,?_HM#\``$F)Q4B%P'2.08!]``"XWUH@`$P/1.A-A?9T#TR)]TR)[NB>/P``
MA<!TRDR)[^BB/P``3`'H2/_(23G%<Q</'X``````@#@O=0O&``!(_\A).<5R
M\$R)[^AX/P``28G$2(G?Z&T_``!,`>!(_\!(/0`$```/@QW___^^V5D@`+GT
M62``3(G_3(GJ28G8,<#HH3X``$R)_TB-M?#Z___H0C\``(7`#X5*____#[>%
M"/O__R4`\```/0"````/A3/___],B?^^`0```.@F/P``A<`/A1[___](C9W0
M^___OZP:(`!(B=[H&@```$B)W^BR/@``2(G#Z:G^___H=3X```\?1```54B)
MY4%7059!54%44TB#[!A(B?M)OP`````!````,?^`/CU`#Y3'2`'W2(E]T.B=
M/@``3(LEEF4``$B%VTB)7<A(B47`="]-A>1T*D4Q[44Q]F9F9F9F+@\?A```
M````0@^V##.%R70E@_D]="!)_\9-`?WKZDF#/"0`=&PQVY!)@WS<"`!(C5L!
M=?3K74V+/"1-A?]T4DG!_2`QV^L.D$V+?-P(2/_#387_=-!,B?](BW7(3(GJ
MZ,0]``"%P'7@0X`\+SUUV4N-/"](_\?H_3T``$B+?<!(.?@/@Q\!``!,BVW0
MZ8`````QVTR+;="`/0)E```!08G>=21*C33U$````$R)Y^CU/0``28G$2(D%
MNV0``$B%P'5"Z=$```#&!=)D```!2HT\]1````#H'3T``$B%P`^$M````$F)
MQTJ-%/4`````2(G'3(GFZ+X]``!,B3UW9```38G\2\=$]`@`````2(M]P#'`
M2(M-R$B^``````$````/'X``````#[81A=)T#8/Z/70(2/_!2`'PZ^Q(P?@@
M2`''2(/'`NBL/```2&/+28D$S$B%P'1`2(L%&60``$B+!,A(BU7(D`^V"H@(
MA<ET#8/Y/70(2/_"2/_`Z^K&`#VY`0```&:000^V5`W_B!0(2/_!A-)U\$B#
MQ!A;05Q!74%>05]=PTECQDP!^$C_P#')2(MUT&:0#[84#H@4"$C_P832=?+K
MT%5(B>534$B)^[XO````Z.T\``!(C7@!2(7`2`]$^TB#Q`A;7>E7/```#Q^`
M`````%5(B>5!5E-(@>P0!```2(L%JV,``$B)1>A(A?]T)4F)_H`_`'0=3(GW
MZ%(\``!(!0#\__](/?_[__]S+3'`Z:$```!(BP5V8P``2#M%Z`^%J0```+_?
M6B``2('$$`0``%M!7EWIYSL``$B-G>#[__](B=],B?;H93P``$B)W^C].P``
M2`'H2`7?^___2#G8=A]F9F9F9F8N#Q^$``````"`."]U"\8``$C_R$@YV'?P
M2(V=X/O__TB)W[XO````Z`P\``!(A<!T$4@YV'8#Q@``2(V]X/O__^L%O]]:
M(`#H;#L``$B+#=5B``!(.TWH=0Q(@<00!```6T%>7</H'CL``&9F9F9F+@\?
MA```````54B)Y4%7059!54%44U!(BQ5;8@``2(72#X3?"0``2;T``````0``
M`#';N+Q9(`"0#[8(A<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$``````!,BS)-
MA?8/A'T```!(P?L@2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])@\0(387V=%6^
MO%D@`$R)]TB)VNB0.@``A<!UW$&`/!X]==5)P?\@2(M%T$J-!/A(@\`(#Q]$
M``!(BPA(B4CX2(/`"$B%R77P2(L5J6$``$B%T@^%6/___^DH"0``2(M5T+AR
M&R``,=L/M@B%R709@_D]=!1(_\!,`>OK[&9F9BX/'X0``````$R+,DV%]@^$
M?0```$C!^R!(B5703(UB"$4Q_^L3#Q\`38LT)$T![TF#Q`A-A?9T5;YR&R``
M3(GW2(G:Z.`Y``"%P'7<08`\'CUUU4G!_R!(BT702HT$^$B#P`@/'T0``$B+
M"$B)2/A(@\`(2(7)=?!(BQ7Y8```2(72#X59____Z7@(``!(BU70N+U:(``Q
MVP^V"(7)=!F#^3UT%$C_P$P!Z^OL9F9F+@\?A```````3(LR387V#X1]````
M2,'[($B)5=!,C6((13'_ZQ,/'P!-BS0D30'O28/$"$V%]G15OKU:(`!,B?=(
MB=KH,#D``(7`==Q!@#P>/7752<'_($B+1=!*C03X2(/`"`\?1```2(L(2(E(
M^$B#P`A(A<EU\$B+%4E@``!(A=(/A5G____IR`<``$B+5="X7UH@`#';#[8(
MA<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$``````!,BS)-A?8/A'T```!(P?L@
M2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])@\0(387V=%6^7UH@`$R)]TB)VNB`
M.```A<!UW$&`/!X]==5)P?\@2(M%T$J-!/A(@\`(#Q]$``!(BPA(B4CX2(/`
M"$B%R77P2(L5F5\``$B%T@^%6?___^D8!P``2(M5T+AZ&R``,=L/M@B%R709
M@_D]=!1(_\!,`>OK[&9F9BX/'X0``````$R+,DV%]@^$?0```$C!^R!(B570
M3(UB"$4Q_^L3#Q\`38LT)$T![TF#Q`A-A?9T5;YZ&R``3(GW2(G:Z-`W``"%
MP'7<08`\'CUUU4G!_R!(BT702HT$^$B#P`@/'T0``$B+"$B)2/A(@\`(2(7)
M=?!(BQ7I7@``2(72#X59____Z6@&``!(BU70N&M:(``QVP^V"(7)=!F#^3UT
M%$C_P$P!Z^OL9F9F+@\?A```````3(LR387V#X1]````2,'[($B)5=!,C6((
M13'_ZQ,/'P!-BS0D30'O28/$"$V%]G15OFM:(`!,B?=(B=KH(#<``(7`==Q!
M@#P>/7752<'_($B+1=!*C03X2(/`"`\?1```2(L(2(E(^$B#P`A(A<EU\$B+
M%3E>``!(A=(/A5G____IN`4``$B+5="X:1L@`#';#[8(A<ET&8/Y/7042/_`
M3`'KZ^QF9F8N#Q^$``````!,BS)-A?8/A'T```!(P?L@2(E5T$R-8@A%,?_K
M$P\?`$V+-"1-`>])@\0(387V=%6^:1L@`$R)]TB)VNAP-@``A<!UW$&`/!X]
M==5)P?\@2(M%T$J-!/A(@\`(#Q]$``!(BPA(B4CX2(/`"$B%R77P2(L5B5T`
M`$B%T@^%6?___^D(!0``2(M5T+C@62``,=L/M@B%R709@_D]=!1(_\!,`>OK
M[&9F9BX/'X0``````$R+,DV%]@^$?0```$C!^R!(B5703(UB"$4Q_^L3#Q\`
M38LT)$T![TF#Q`A-A?9T5;[@62``3(GW2(G:Z,`U``"%P'7<08`\'CUUU4G!
M_R!(BT702HT$^$B#P`@/'T0``$B+"$B)2/A(@\`(2(7)=?!(BQ797```2(72
M#X59____Z5@$``!(BU70N)):(``QVP^V"(7)=!F#^3UT%$C_P$P!Z^OL9F9F
M+@\?A```````3(LR387V#X1]````2,'[($B)5=!,C6((13'_ZQ,/'P!-BS0D
M30'O28/$"$V%]G15OI):(`!,B?=(B=KH$#4``(7`==Q!@#P>/7752<'_($B+
M1=!*C03X2(/`"`\?1```2(L(2(E(^$B#P`A(A<EU\$B+%2E<``!(A=(/A5G_
M___IJ`,``$B+5="X5AL@`#';#[8(A<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$
M``````!,BS)-A?8/A'T```!(P?L@2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])
M@\0(387V=%6^5AL@`$R)]TB)VNA@-```A<!UW$&`/!X]==5)P?\@2(M%T$J-
M!/A(@\`(#Q]$``!(BPA(B4CX2(/`"$B%R77P2(L5>5L``$B%T@^%6?___^GX
M`@``2(M5T+BL&B``13'V9F9F9F9F+@\?A```````#[8(A<ET&8/Y/7042/_`
M30'NZ^QF9F8N#Q^$``````!(B5702(L:2(7;#X2?````2<'^($B+1=!,C6`(
M13'M28G?ZR9F9F8N#Q^$``````!-BSPD2+@``````0```$D!Q4F#Q`A-A?]T
M9;ZL&B``3(G_3(GRZ(8S``"%P'720X`\-SUURTG!_2!(BT702HT$Z$B#P`AF
M9BX/'X0``````$B+"$B)2/A(@\`(2(7)=?!(BQ696@``2(722;T``````0``
M``^%'____^D.`@``N'=:(`!%,?9)O0`````!````3(MET&9F+@\?A```````
M#[8(A<ET#8/Y/70(2/_`30'NZ^Q(A=MT5DG!_B!-C7PD".L89F9F+@\?A```
M````28L?28/'"$B%VW0SOG=:(`!(B=],B?+HQ#(``(7`=>!"@#PS/7792HTT
M,TC_QK^26B``Z"CT__],BR7Q60``387D#X1U`0``N#@;(``QVY`/M@B%R70-
M@_D]=`A(_\!,`>OK[$V+-"1-A?9T6TC!^R!-C7PD".L4#Q^$``````!-BS=)
M@\<(387V=#.^.!L@`$R)]TB)VNA$,@``A<!UX$&`/!X]==E)C30>2/_&OQ<<
M(`#HJ//__TR+)7%9``!-A>0/A/4```"X^%D@`$4Q]@^V"(7)=`V#^3UT"$C_
MP$T![NOL3(EET$F+'"1(A=MT44G!_B!(BT703(U@"$F)W^L;9F9F9F8N#Q^$
M``````!-BSPD28/$"$V%_W0EOOA9(`!,B?],B?+HLS$``(7`==]#@#PW/778
M30'WOVD;(`#K<+@B'"``13'V3(M]T&:0#[8(A<ET#8/Y/70(2/_`30'NZ^Q(
MA=MT5$G!_B!)@\<(ZQEF9F9F+@\?A```````28L?28/'"$B%VW0QOB(<(`!(
MB=],B?+H1#$``(7`=>!"@#PS/7793`'SO^!9(`!)B=])_\=,B?[HH_+__[]Z
M&R``OC8;(`!(@\0(6T%<05U!7D%?7>F&\O__9@\?1```54B)Y4%7059!5%-,
MBR4^6```387D#X2%````N.!9(``QVTBY``````$````/'T``#[80A=)T#8/Z
M/70(2/_`2`'+Z^Q-BSPD13'V387_=%-(P?L@28/$".L39@\?1```38L\)$F#
MQ`A-A?]T-K[@62``3(G_2(G:Z(,P``"%P'7?08`\'SUUV$$/MD0?`83`#Y7!
M/#`/E<`@R$0/MO#K`T4Q]D2)\%M!7$%>05]=PY!52(GE2('LT````$F)^DB)
MM3C___](B95`____2(F-2/___TR)A5#___],B8U8____A,!T)@\IA6#___\/
M*8UP____#RE5@`\I79`/*66@#REML`\I=<`/*7W02(V%,/___TB)1?!(C440
M2(E%Z$BX"````#````!(B47@2(L]G5<``$B-5>!,B=;H@3```+__````Z(<P
M```/'X``````54B)Y>B',```B<?HD#```$B%P'0%2(L`7<,QP%W#9I!52(GE
M05=!5D%44TB)^TR+)<M6``!-A>0/A+4```"XX5H@`$4Q]DBY``````$````/
MMA"%TG0-@_H]=`A(_\!)`<[K[$V+/"1-A?\/A((```!)P?X@28/$".L2#Q]$
M``!-BSPD28/$"$V%_W1FON%:(`!,B?],B?+H$R\``(7`==]#@#PW/77830'^
M2?_&3(GWZ$HO``!(A<!T.$F)QTB)W^@Z+P``28T\!TB#QP+HK2X``$F)Q[[9
M62``N?99(`!(B<=(B=I-B?`QP.AP+@``3(G[O^%:(`!(B=Y;05Q!7D%?7>DH
M\/__#Q^$``````!52(GE05=!5D%505132('L.``!`$F)_$B+!1)6``!(B470
M2(L=QU4``$B%VP^$M@```+AI&R``13'V2+H``````0```&9F9BX/'X0`````
M``^V"(7)=`V#^3UT"$C_P$D!UNOL3(L[387_='Q)P?X@2(/#".L69BX/'X0`
M`````$R+.TB#PPA-A?]T7+YI&R``3(G_3(GRZ`0N``"%P'7@0X`\-SUUV4.`
M?#<!`'0Y2XT<-TC_PTB)W^A2_O__2(L%:U4``$@[1=`/A54)``!(B=](@<0X
M``$`6T%<05U!7D%?7>G8+0``3(FEL/_^_^B,+@``B<?HE2X``$B%P'0,2(L`
M2(7`#X4F`0``2(L=W50``$B%VP^$%`$``+@J&R``13'V2+H``````0```&:0
M#[8(A<ET#8/Y/70(2/_`20'6Z^Q,BSM-A?]T8DG!_B!,C6,(ZQ=F+@\?A```
M````38L\)$F#Q`A-A?]T.+XJ&R``3(G_3(GRZ",M``"%P'7?0X`\-SUUV$.`
M?#<!`'052XT\-TC_Q^@D+0``2(7`#X6-````2(7;#X2"````N+\:(`!%,?9(
MN@`````!````#[8(@_D]=`R%R70(2/_`20'6Z^Q,BSM-A?]T5$G!_B!(@\,(
MZQ9F+@\?A```````3(L[2(/#"$V%_W0TOK\:(`!,B?],B?+HE"P``(7`=>!#
M@#PW/7790X!\-P$`=!%+C3PW2/_'Z)4L``!(A<!U`C'`2(7`0;XO&R``3`]%
M\$R)]^BI+```2(T\`$C_Q^@=+```28G'00^V!H3`=#-)_\9,B?MF9F8N#Q^$
M```````/MM"^C5H@`$B)WS'`Z,XK``!(@\,"00^V!DG_QH3`==],B;VH__[_
M13'VZS!(B=^^`@```.AF+```A<`/A`<!``!F9F9F9BX/'X0``````$G_QDF#
M_@4/A/P```!,BST<4P``387_=.=.BRSU$%L@`$4QY$R)Z$BZ``````$```!F
M9F9F9F8N#Q^$```````/M@B%R709@_D]=!1(_\!)`=3K[&9F9BX/'X0`````
M`$F+'TB%VW282<'\($F#QPCK'F9F9F9F+@\?A```````28L?28/'"$B%VP^$
M</___TB)WTR)[DR)XNA"*P``A<!UWD*`/",]==="@'PC`0`/A$O___],`>-(
M_\-(B=](C;7`__[_Z!8L``"%P`^%+O___P^WA=C__O\E`/```#T`0```#X3T
M_O__/0"@```/A.G^___I!____TB)W^C_*@``28G%2(7`=49(C;7`__[_O[D:
M(`#HQBL``(7`#X2#`0``2(VUP/_^_[_?6B``Z*TK``"_WUH@`+X"````Z`XK
M``"_WUH@`.BT*@``28G%3(GOZ-DJ``!(B<-,B[VH__[_3(G_Z,<J```!V`4$
M!```3&/@3(GGZ#4J``!)B<:^REH@`+GT62``0;@(6B``2(G'3(GJ38GY,<#H
M\BD``$R)][[``0``Z$4K``"#^/]U#NA+*P``@S@1#X4W`0``2(VUP/_^_TR)
M]^@3*P``A<`/A8<````/MYW8__[_B=@E`/```#T`0```=7)$B[W<__[_Z,HJ
M``!!.<=U88'C_P$``('[P`$``'533(GGZ)\I``!)B<=,BRT540``387M#X1B
M`0``N.I9(`!%,>1(N@`````!````9BX/'X0```````^V"(7)#X3@````@_D]
M#X37````2/_`20'4Z^1(BSU-40``2(N%L/_^_TB+$$4Q_[Z*&R``3(GQ,<#H
MD2H``$B+!>I0``!(.T70#X74!```3(GX2('$.``!`%M!7$%=05Y!7UW##[>%
MV/_^_R4`\```/0!```!T"ST`H```#X5?_O__O[D:(`"^`@```.A^*0``A<`/
MA4C^__^_N1H@`.@<*0``28G%2(7`#X5?_O__Z2W^__](BQVT4```2(N%L/_^
M_TR+(.CU*0``1(L`13'_O@U:(`!(B=],B>),B?$QP.CJ*0``Z53___])BUT`
M2(7;=%))P?P@28/%".L/9I!)BUT`28/%"$B%VW0YONI9(`!(B=],B>+H@R@`
M`(7`==]"@#PC/7782HTT(TC_QDB+A;#__O](BSCHHN?__TF)Q$B%P'4*2(N%
ML/_^_TR+($R)Y^B8*```2(G#@_L$3(FEJ/_^_WP=2&/#28T\!$B#Q_R^[UD@
M`.AD*```A<`/A*P"``!(N@`````!````3(LM6T\``$V%[0^$?0```+C@62``
M,=MF9BX/'X0```````^V"(7)=`V#^3UT"$C_P$@!T^OL38ME`$V%Y'1.2,'[
M($F#Q0CK%F8/'X0``````$V+90!)@\4(387D="Z^X%D@`$R)YTB)VNBC)P``
MA<!UWT&`/!P]==A!#[9$'`&#^#!T"(7`#X5U`0``2(N]J/_^_S'V,<#HM2@`
M`(7`#X1=`0``08G%B<<Q]KH"````Z*PH``!)B<1(_\A)C9PD_O\``$B%P$@/
M2=A(@>,``/__#X@J`0``2"G822G$28/$Q42)K;#__O_K)4B-@P``__])@<0`
M`/__2('[__\``$B)PT2+K;#__O\/CO(```!$B>](B=XQTNA%*```2(/X_P^$
M=`(``+H(``$`1(GO3(VMP/_^_TR)[N@T*```@_C_#X1@`@``2&/X2(V-N/_^
M_T@!^4PYZ0^2P??'^/___W2)A,EUA4B-C;C__O]-B>5FD$B+%#E(.Q7=2P``
M=!Y)_\U(C10Y2/_*2/_)2(VUP/_^_T@Y\G/:Z4[___](8\A,`>E(@\$R>%E)
MB<1(F$J--"A(@\8HBYVP__[_B=\QTNB=)P``2(VUNO_^_[H&````B=_HFB<`
M`$B#^`8/A=$!``"X`$-!0S.%NO_^_P^WC;[__O^!\4A%```)P0^$&0$``+_@
M62``OC8;(`#H@>?__^B<)0``OO%:(`"Y]%D@`$&Y:!L@`$R)_TR)\D&)P#'`
MZ(PE``!,B?^^P`$``.C?)@``@_C_#X4H`0``NP$```#HW"8``(,X$0^%%0$`
M`.A.)0``2,<$)&@;(`"^$1L@`+GT62``3(G_3(GR08G`08G9,<#H.24``$R)
M_[[``0``Z(PF``#_PX/X_W2TZ=(```"#^P1(N@`````!````="!(P>,@2+@`
M````^____T@!V$C!^"!!@#P$+P^%+_W__TB+A;#__O](BU@(2(7;#X0;_?__
M2(G?Z'4E``!(@_@$#X+__/__2(T\`TB#Q_R^B%H@`.A))0``A<!,#T3C3(FE
MJ/_^_^G;_/__26/T3`'NBYVP__[_B=\QTN@R)@``2(VUP/_^_[HH````B=_H
M+R8``$B#^"AU:L:%Z/_^_P!,C87`__[_ON@;(`"Y]%D@`$&Y:!L@`$R)_TR)
M\C'`Z$XD``!,B??H!B8``+]I&R``3(G^Z`GF__],B?_H\?3__^D;^___Z&<D
M``"_S%D@`#'`Z!OT__^_2AL@`#'`Z`_T__^_W1L@`#'`Z`/T__\/'P!52(GE
M05=!5D%44TR+)8Y+``!-A>0/A,0```!(B?NXX%D@`$4Q]DBY``````$````/
MMA"%TG0-@_H]=`A(_\!)`<[K[$V+/"1-A?\/A(X```!)P?X@28/$".L2#Q]$
M``!-BSPD28/$"$V%_W1RON!9(`!,B?],B?+HTR,``(7`==]#@#PW/7782(7;
M=%)##[9$-P&%P'1(@_@P=$.`.P!T/DB)W^AWY___28G&2(G'OB\```#H-R0`
M`$B->`%(A<!)#T3^Z*<C``"^"%H@`+H$````2(G'Z'4C``"%P'0)6T%<05Y!
M7UW#2(G?6T%<05Y!7UWK"V9F+@\?A```````54B)Y4%7059!54%44TB![.@`
M``!(BP7%2@``2(E%T$B%_P^$`P$``$B)^X`_``^$]P```$B)W^B4)```2(7`
M#X3F````28G&2(G'Z)`D``!(A<`/A/$```!)B<1,C;WP_O__ZR]F9BX/'X0`
M`````$R)[^AX)```3(GOZ$`D``!,B??H6"0``$F)Q$B%P`^$M@```$F#Q!B^
MWUH@`$R)Y^CK(@``A<!TU[[(&B``3(GGZ-HB``"%P'3&2(G?Z-XB``!)B<5,
MB>?HTR(``$0!Z(/``DAC^.A%(@``28G%OO<;(`!(B<=(B=I,B>$QP.@-(@``
M3(GO3(G^Z+(B``"#^/\/A&G___\/MX4(____)0#P```]`$````^%4O___TR)
M[^C:_O__Z4W___](BP6N20``2#M%T'5`2('$Z````%M!7$%=05Y!7UW#3(GW
MZ*XC``!(BP6'20``2#M%T'492(G?2('$Z````%M!7$%=05Y!7UWIF",``.C#
M(0``#Q\`54B)Y4%7059!54%44TB![!@$``!(BP5%20``2(E%T$F\``````$`
M``!(BP70-@``9$B+#"4`````3(TL`4B+!`$/MHBP````B(BQ````3(L]RT@`
M`$V%_W1]N'H;(``QVV9F9F9F9BX/'X0```````^V"(7)=`V#^3UT"$C_P$P!
MX^OL38LW387V=$M(P?L@28/'".L69BX/'X0``````$V+-TF#QPA-A?9T*[YZ
M&R``3(GW2(G:Z!0A``"%P'7@08`\'CUUV4&`?!X!,74(08!\'@(`=`7HU.7_
M_TF+?0"^2%H@`+H!````N0,```#HK"(``$B%P'0I2(G#28M]`$B+0!!(BS"Z
M9EH@`.B?(@``2(M#$$B+,/9&#D`/A6$"``!)BWT`OLL:(`"Z`0```+D#````
MZ&8B``!(A<`/A"P!``!(B<-,B:W(^___3(LMS$<``$V%[0^$B0```+BL&B``
M13'V9F8N#Q^$```````/M@B%R70-@_D]=`A(_\!-`>;K[$V+?0!-A?]T64G!
M_B!)@\4(ZQ9F#Q^$``````!-BWT`28/%"$V%_W0YOJP:(`!,B?],B?+H$R``
M`(7`==]#@#PW/7782XT4-TC_PDR+K<C[__])BWT`2(M#$$B+,.F$````2(M#
M$$B+&$B+!3Q'``!,BS!(C;70^___OZE9(`"Z_P,``.B#'P``A<!,BZW(^___
M?DA!C0P$_\F`O`W0^___`'4$_\AT-$&)QTB-O=#[__^^+P```$R)^NA](0``
M2(7`=!A)BWT`2(V5T/O__TB)WDR)^>AR(0``ZP])BWT`2(G>3(GRZ$$A``!)
MBUT`ODI:(`!(B=^Z`0```.A;(0``NC,<(`!(B=](B<;H&R$``$F+10#&@+$`
M````3(L]>48``$V%_W1[N&D;(``QVV9F9F8N#Q^$```````/M@B%R70-@_D]
M=`A(_\!,`>/K[$V+-TV%]G1+2,'[($F#QPCK%F8N#Q^$``````!-BS=)@\<(
M387V="N^:1L@`$R)]TB)VNC$'@``A<!UX$&`/!X]==E)C3P>2/_'2(D]$T8`
M`.LF2,<%!D8```````!(BSWW10``Z/+O__](B<=(B07P10``2(7`=$F^P`$`
M`.B)'P``C4@!@_D"<@6#^!%U/DB+!?5%``!(.T70=2!(@<08!```6T%<05U!
M7D%?7<-)BWT`Z&0@``#ID?W__^@J'@``OYQ:(``QP.A>(```2(L-AT4``$B+
M,4B+%85%``"_S1H@`(G!,<#H/R```&9F9F9F9BX/'X0``````%5(B>5!5T%6
M055!5%-(@^PH2(L%>$4``$B)1=")?<Q(B77`2(E5N$B-?<Q(C77`2(U5N.@(
M(```O^"U(`"^\+4@`+KPM2``Z"0@``"`/8U%````=!)D2(L$)0````!(`P7+
M,@``ZSSH%"```$B)!?U$``!(A<`/A`P#``!(B<?H#"```$B+#:4R``!D2(L4
M)0````!(C00*2(L,"L:!I@@```!(BPB`B2($```"2(L`@(@B!````4AC1<R-
M6`-(C3S%(````.C5'P``2(D%CD0``$B+=<!(BPY(B0A(QT`(#AL@`$B+#55"
M``!(B4@02,=`&"(;(`"+3<RZ!````(/Y`@^,W````+\!````@_D)<E1)B<!)
M*?!)@\`828/X(')$3(U!_TV)P4F#X?Q)C7D!28U1!$4QT@\?A```````0@\0
M1-8(0@\03-880@\11-`@0@\13-`P28/"!$TYT77?33G(='Q!B<E!*?E)B?A)
M]]!)`<A)@^$#=!@/'T0``$R+%/Y,B1302/_"2/_'2?_)=>U)@_@#<DE(*?E(
MC3S^2(/'&$R-!-!)@\`8,?9FD$R+3/?H38E,\.A,BTSW\$V)3/#P3(M,]_A-
MB4SP^$R+#/=-B0SP2(/&!$@Y\7712`'RB=)(QP30`````$B+/7U#``"^,)D@
M`(G:2(G!13'`Z*L>``"%P'4,2(L]8$,``.BK'@``2(L]5$,``.BO'@``3(LM
M*$,``$V%[8E%M`^$L````+IK6B``2+X``````0```$4Q_V8N#Q^$```````/
MM@J%R70-@_D]=`A(_\))`??K[$V+=0!-A?9T/TG!_R!)C5T(38GTZQ)F#Q]$
M``!,BR-(@\,(387D=""^:UH@`$R)YTR)^NAD&P``A<!UX$.`/#P]==GIIP``
M`$B+/;5"``!(A?]U.+AI&R``13'_2+H``````0```&8/'T0```^V"(7)=""#
M^3UT&TC_P$D!U^OL2(L]?4(``$B%_W18Z+OV___K7$V%]G1,2<'_($F#Q0CK
M%V8N#Q^$``````!-BW4`28/%"$V%]G0KOFD;(`!,B?=,B?KHTQH``(7`==]#
M@#P^/7782XT\/DC_QTB)/2)"``#KJ$C'!15"````````2(L]%D(``.B!'0``
MZ(P=``!(BP4E0@``2#M%T'42BT6T2(/$*%M!7$%=05Y!7UW#Z&@:``"_`0``
M`.@^&P``9F9F9F8N#Q^$``````!52(GE05932(L=@B\``&1,BS0E`````$F+
M/!Z^D!H@`+H0LR``N0!;(`#HP1D``$F+/!Z^_1L@`+K`D2``N6@;(`!!N&@;
M(`!%,<E;05Y=Z0P=``#,S,S,S,S,S,S,S,Q52(GEOX````#HPAD``$C'``$C
M16>Y_MRZF$B-D8O.$E=(B5`(2(E($$C'0!AV5#(02('!\@08*TB)2"#'0'@`
M````#U?`#Q%`*%W##Q]``%5(B>5!5T%6055!5%-008G62(G[2(M'*$ACRHT4
MR$C!Z1U(.<)(B5<H2!%/,$F)]TAC1WA(A<!T1+E`````*<%$.?%!#TW.2(T\
M`TB#QSA,8^%,B?Y,B>+H,QD``(M#>$0!X(E#>(/X0`^%?P```$T!YT4IYDB)
MW^B#````08/^0'Q23(UC.&8/'X0``````$$/$`=!#Q!/$$$/$%<@00\07S!!
M#Q%<)#!!#Q%4)"!!#Q%,)!!!#Q$$)$F#QT!%C6[`2(G?Z#8```!!@_Y_18GN
M=[WK`T6)]4B->SA-8_5,B?Y,B?+HIA@``$2)<WA(@\0(6T%<05U!7D%?7<,/
M'P!52(GE05=!5D%505132('LJ`(``$B+!25```!(B4702(M'.(G!#\E(B8U0
M_?__2(G!2,'I(,'A&$B)PDC!ZAB!X@``_P!(B<9(P>XH@>8`_P``2,'H.$@)
M\$@)T$@)R$B)A5C]__](BT=`B<$/R4B)C6#]__](B<%(P>D@P>$82(G"2,'J
M&('B``#_`$B)QDC![BB!Y@#_``!(P>@X2`GP2`G02`G(2(F%:/W__TB+1TB)
MP0_)2(F-</W__TB)P4C!Z2#!X1A(B<)(P>H8@>(``/\`2(G&2,'N*('F`/\`
M`$C!Z#A("?!("=!("<A(B85X_?__2(M'4(G!#\E(B8V`_?__2(G!2,'I(,'A
M&$B)PDC!ZAB!X@``_P!(B<9(P>XH@>8`_P``2,'H.$@)\$@)T$@)R$B)A8C]
M__](BT=8B<$/R4B)C9#]__](B<%(P>D@P>$82(G"2,'J&('B``#_`$B)QDC!
M[BB!Y@#_``!(P>@X2`GP2`G02`G(2(F%F/W__TB+1V")P0_)2(F-H/W__TB)
MP4C!Z2#!X1A(B<)(P>H8@>(``/\`2(G&2,'N*('F`/\``$C!Z#A("?!("=!(
M"<A(B86H_?__2(M':(G!#\E(B8VP_?__2(G!2,'I(,'A&$B)PDC!ZAB!X@``
M_P!(B<9(P>XH@>8`_P``2,'H.$@)\$@)T$@)R$B)A;C]__](BT=PB<$/R4B)
MC<#]__](B<%(P>D@P>$82(G"2,'J&('B``#_`$B)QDC![BB!Y@#_``!(P>@X
M2`GP2`G02`G(2(F%R/W__[@0````#Q]``$B+C,40_?__2#.,Q3C]__](,XS%
MX/S__T@SC,70_/__C10)2,'I'PG12(F,Q5#]__](_\!(@_A0=<9,BP=(BU<(
M2(MW$$B+3QA(BT<@2(F%2/W__TV)PDB)T$C!X!Y)B=%)P>D"20G!1(G+1"'#
M38G&38G'38G#1(MER$4!Q$G!X`5)P>H;30G"2(GP28G02(F5./W__T@AT$P!
MT$GWT$B)C4#]__])(<A,`X5(_?__20'`2(N%4/W__TP!P$@%F7F"6D&)Q4GW
MUDDA]DD!SDD!WDV)Z$P#M5C]__])P>@;30'&08G`0<'@!4T!\$F!P)EY@EI)
MP><>2<'K`DT)^T6)VD4QRD$APD4QRDB+G6#]__](`?-,`=-%B<9-B?))P>H;
M3`'318G"0<'B!4D!VDF!PIEY@EK!X!Y)P>T"3`GHB<-$,=M$(<-$,=M,`XUH
M_?__20'91(G328G?2<'O&TT!^46)UT'!YP5-`?E)@<&9>8):0<'@'DG![@)-
M"?!%B<9!,<9%(=9!,<9,`YUP_?__30'S18G.38GW2<'O&TT!^T6)ST'!YP5-
M`?M)@<.9>8):0<'B'DC!ZP))"=I$B=-$,<-$(<M(`X5X_?__1#'#2`'818G?
M3(G[2,'K&T@!V$2)V\'C!4@!PTB!PYEY@EI!P>$>2<'N`DT)\42)R$0QT$0A
MV$0QT$P#A8#]__])`<")V$F)QDG![AM-`?!!B=Y!P>8%30'P28'`F7F"6D'!
MXQY)P>\"30G[18G>13'.02'>13'.3`.5B/W__TT!\D6)QDV)]TG![QM-`?I%
MB<=!P><%30'Z28'"F7F"6L'C'DC!Z`)("<.)V$0QV$0AP$0QV$P#C9#]__])
M`<%$B=!)B<=)P>\;30'Y18G70<'G!4T!^4F!P9EY@EI!P>`>2<'N`DT)\$6)
MQD$QWD4AUDP#G9C]__]!,=Y-`?-%B<Y-B?=)P>\;30'[18G/0<'G!4T!^TF!
MPYEY@EI!P>(>2,'H`DD)PD2)T$0QP$0AR$0QP$@#G:#]__](`<-$B=A)B<=)
MP>\;3`'[18G?0<'G!4P!^TB!PYEY@EI!P>$>2<'N`DT)\46)SD4QUD4AWD4Q
MUDP#A:C]__]-`?!!B=Y-B?=)P>\;30'X08G?0<'G!4T!^$F!P)EY@EI!P>,>
M2,'H`DD)PT2)V$0QR"'81#'(3`.5L/W__TD!PD2)P$F)QTG![QM-`?I%B<=!
MP><%30'Z28'"F7F"6L'C'DG![@),"?-!B=Y%,=Y%(<9,`XVX_?__13'>30'Q
M18G638GW2<'O&TT!^46)UT'!YP5-`?E)@<&9>8):0<'@'DC!Z`))"<!$B<`Q
MV$0AT#'83`.=P/W__TD!PT6)STR)^$C!Z!M)`<-$B<C!X`5)`<-)@<.9>8):
M0<'B'DG![@)-"?)$B=!$,<!$(<A$,<!(`YW(_?__2`'#18G>3(GP2,'H&T@!
MPT2)V,'@!4@!V$@%F7F"6D'!X1Y)P>\"30GY1(G+1#'31"';1#'33`.%T/W_
M_TD!V(G#28G?2<'O&TT!^$&)QT'!YP5-`?A)@<"9>8):0<'C'DG![@)-"?-%
MB=Y%,<Y!(<9,`Y78_?__13'.30'R18G&38GW2<'O&TT!^D6)QT'!YP5-`?I)
M@<*9>8):P>`>2,'K`D@)V(G#1#';1"'#1#';3`.-X/W__TD!V42)TTF)WTG!
M[QM-`?E)B=])P><%30'Y28'!F7F"6D'!X!Y)P>X"30GP18G&03'&12'603'&
M3`.=Z/W__TT!\T6)SDV)]TG![QM-`?M-B?=)P><%30'[28'#F7F"6D'!XAY(
MP>L"20G:3(G33#'#3#'+2`.%\/W__T@!V$2)VTF)WTG![QM,`?A)B=])P><%
M3`'X2`6AZ]EN0<'A'DG![@)-"?%-B<Y-,=9-,=Y,`X7X_?__30'P08G&38GW
M2<'O&TT!^$V)]TG!YP5-`?A)@<"AZ]EN0<'C'DC!ZP))"=M,B=M,,<M(,<-,
M`Y4`_O__20':1(G#28G?2<'O&TT!^DF)WTG!YP5-`?I)@<*AZ]ENP>`>2<'N
M`DP)\$F)QDTQWDTQQDP#C0C^__]-`?%%B=9-B?=)P>\;30'Y38GW2<'G!4T!
M^4F!P:'KV6Y!P>`>2,'K`DD)V$R)PT@QPTPQTTP#G1#^__])`=M$B<M)B=])
MP>\;30'[28G?2<'G!4T!^TF!PZ'KV6Y!P>(>2<'N`DT)\DV)UDTQQDTQSD@#
MA1C^__],`?!%B=Y-B?=)P>\;3`'X38GW2<'G!4P!^$@%H>O9;D'!X1Y(P>L"
M20G93(G+3#'33#';3`.%(/[__TD!V(G#28G?2<'O&TT!^$F)WTG!YP5-`?A)
M@<"AZ]EN0<'C'DG![@)-"?--B=Y-,<Y),<9,`Y4H_O__30'R18G&38GW2<'O
M&TT!^DV)]TG!YP5-`?I)@<*AZ]ENP>`>2,'K`D@)V$B)PTPQVTPQPTP#C3#^
M__])`=E$B=-)B=])P>\;30'Y28G?2<'G!4T!^4F!P:'KV6Y!P>`>2<'N`DT)
M\$V)QDDQQDTQUDP#G3C^__]-`?-%B<Y-B?=)P>\;30'[38GW2<'G!4T!^TF!
MPZ'KV6Y!P>(>2,'K`DD)VDR)TTPQPTPQRT@#A4#^__](`=A%B=],B?M(P>L;
M2`'83(G[2,'C!4@!V$@%H>O9;D'!X1Y)P>X"30GQ3(G+3#'33#';3`.%2/[_
M_TD!V$&)Q4R)ZTC!ZQM)`=A,B>M(P>,%3`'#2('#H>O9;D'!XQY)P>\"30G[
M38G833'(23'`3`.54/[__TT!PD&)V$V)QDG![AM-`?)-B<9)P>8%30'628'&
MH>O9;L'@'DG![0),">A)B<)-,=I),=I,`XU8_O__30'118GW38GZ2<'J&TT!
MT4V)^DG!X@5-`<I)@<*AZ]ENP>,>2<'H`DP)PTF)V$DQP$TQ\$P#G6#^__]-
M`<-%B=5-B>A)P>@;30'#38GH2<'@!4T!V$F!P*'KV6Y!P>8>2<'O`DT)_DV)
M\4DQV4TQT4@#A6C^__],`<A%B<--B=E)P>D;3`'(38G92<'A!4D!P4F!P:'K
MV6Y!P>(>2<'M`DT)ZD2)T$0Q\$0QP`.=</[__P'#1(G(28G'2<'O&T$!WT2)
MR\'C!40!^X'#H>O9;D'!X!Y)P>L"30G818G#13'313'+1`.U>/[__T4!WDF)
MVTG!ZQM%`?-!B=Y!P>8%1XT\'D&!QZ'KV6Y!P>$>2,'H`DD)P42)^,'@!4V)
MRTTQPTDQVTP#E8#^__]-`=I-B?M)P>L;30':3HTT$$F!QJ'KV6Y$B?!!B=M!
MP>,>2,'K`DD)VTV)VDTQRDTQ^DP#A8C^__]-`=!)B<))P>H;30'018GR0<'B
M!4N-'`)(@<.AZ]EN18GZ0<'B'DG![P)-"?I%B=!%"=A%(?!%B==%(=]%"<=,
M`XV0_O__30'Y08G80<'@!4T!P4&)WTV)^$G!Z!M-`<%!P>8>2,'H`DD)QD2)
M\$0)T"'818GP12'03`.=F/[__T$)P$T!PT&XW+P;CTT!P42)R,'@!4D!PT2)
MR$F)Q4G![1M-`>O!XQY)P>\"3`G[08G?10GW12'/08G=12'U10G]3`.5H/[_
M_TT!ZDT!PT6)WT'!YP5-`?I%B=]-B?U)P>T;30'J0<'A'DC!Z`))"<%$B<@)
MV$0AV$6)S4$AW4$)Q4P#M:C^__]-`>Y-`<)$B=#!X`5)`<9$B=!)B<5)P>T;
M30'N0<'C'DG![P)-"?M%B=]%"<]%(==%B=U%(<U%"?U(`YVP_O__3`'K30'&
M18GW0<'G!4P!^T6)]TV)_4G![1M,`>M!P>(>2,'H`DD)PD2)T$0)V$0A\$6)
MU44AW4$)Q4P#C;C^__]-`>E,`<.)V,'@!4D!P8G828G%2<'M&TT!Z4'!YAY)
MP>\"30G^18GW10G702'?18GU12'510G]3`.=P/[__TT!ZTT!P46)ST'!YP5-
M`?M%B<]-B?U)P>T;30'KP>,>2,'H`D@)PXG81`GP1"'(08G=12'U00G%3`.5
MR/[__TT!ZDT!PT2)V,'@!4D!PD2)V$F)Q4G![1M-`>I!P>$>2<'O`DT)^46)
MST$)WT4AWT6)S4$AW44)_4P#M=#^__]-`>Y-`<)%B==!P><%30'^18G738G]
M2<'M&TT![D'!XQY(P>@"20G#1(G81`G(1"'018G=12'-00G%2`.=V/[__TP!
MZTT!QD2)\,'@!4@!PT2)\$F)Q4G![1M,`>M!P>(>2<'O`DT)^D6)UT4)WT4A
M]T6)U44AW44)_4P#C>#^__]-`>E,`<-!B=]!P><%30'Y08G?38G]2<'M&TT!
MZ4'!YAY(P>@"20G&1(GP1`G0(=A%B?5%(=5!"<5,`YWH_O__30'K30'!1(G(
MP>`%20'#1(G(28G%2<'M&TT!Z\'C'DG![P),"?M!B=]%"?=%(<]!B=U%(?5%
M"?U,`Y7P_O__30'J30'#18G?0<'G!4T!^D6)WTV)_4G![1M-`>I!P>$>2,'H
M`DD)P42)R`G81"'818G-02'=00G%3`.U^/[__TT![DT!PD2)T,'@!4D!QD2)
MT$F)Q4G![1M-`>Y!P>,>2<'O`DT)^T6)WT4)ST4AUT6)W44AS44)_4@#G0#_
M__],`>M-`<9%B?=!P><%3`'[18GW38G]2<'M&TP!ZT'!XAY(P>@"20G"1(G0
M1`G81"'P18G512'=00G%3`.-"/___TT!Z4P!PXG8P>`%20'!B=A)B<5)P>T;
M30'I0<'F'DG![P)-"?Y%B?=%"==!(=]%B?5%(=5%"?U,`YT0____30'K30'!
M18G/0<'G!4T!^T6)STV)_4G![1M-`>O!XQY(P>@"2`G#B=A$"?!$(<A!B=U%
M(?5!"<5,`Y48____30'J30'#1(G8P>`%20'"18G=3(GH2,'H&TD!PD'!X1Y)
MP>\"30GY1(G("=A$(=A%B<]!(=]!"<=,`[4@____30'^30'"18G73(GX2,'H
M&TD!QDR)^$C!X`5,`<!,`?!!P>,>2<'M`DT)ZT6)W44)S44AU4'!XAY)P>\"
M30GZB<))B==)P><%30''3(G13#'928'`^@1'.TR+M3C___]-`<9-`=Y%(<M%
M">M(`YTH____3`';28G32<'K&TP!VTD!WTR+K3#___]-`<5-`<U(,<%)`<U$
MB?E)B<E)P>D;30'-28G)2<'A!4T!S<'@'DC!Z@)("=!(B<),,=),,?I)`=9$
MB>I)B=%)P>D;30'.28G12<'A!4T!SD'!YQY(P>D"20G/3(N-0/___TT!P4T!
MT4R)^4@QP4PQZ4D!R42)\4F)RDG!ZAM-`=%)B<I)P>(%30'10<'E'DC!Z@))
M"=5,BY5(____30'"20'"3(GH3#'X3#'P20'"1(G(2(G"2,'J&TD!TDB)PDC!
MX@5)`=)!P>8>2,'I`DD)SDR+G5#___]-`<--`?M,B?%,,>E,,<E)`<M$B=%(
MB<I(P>H;20'32(G*2,'B!4D!TT'!X1Y(P>@"20G!2(N=6/___TP!PTP!ZTR)
MR$PQ\$PQT$@!PT2)V$B)PDC!ZAM(`=-(B<)(P>(%2`'30<'B'DC!Z0))"<I,
MB[U@____30''30'W3(G13#')3#'920'/B=E(B<I(P>H;20'72(G*2,'B!4D!
MUT'!XQY(P>@"20G#3(NU:/___TT!QDT!SDR)V$PQT$@QV$D!QD2)^$B)PDC!
MZAM)`=9(B<)(P>(%20'6P>,>2,'I`D@)RTR+C7#___]-`<%-`=%(B=E,,=E,
M,?E)`<E$B?%(B<I(P>H;20'12(G*2,'B!4D!T4'!YQY(P>@"20G'3(N5>/__
M_TT!PDT!VDR)^$@QV$PQ\$D!PD2)R$B)PDC!ZAM)`=)(B<)(P>(%20'20<'F
M'DC!Z0))"<Y,BVV`30'%20'=3(GQ3#'Y3#')20'-1(G12(G*2,'J&TD!U4B)
MRDC!X@5)`=5!P>$>2,'H`DD)P4R+78A-`<--`?M,B<A,,?!,,=!)`<-$B>I(
MB=!(P>@;20'#2(G02,'@!4D!PT'!XAY(P>D"20G*2(M%D$P!P$P!\$R)T4PQ
MR4PQZ4@!R$2)V4B)RTC!ZQM(`=A(B<M(P>,%2`'80<'E'DC!Z@))"=5,BW68
M30'&30'.3(GJ3#'23#':20'6B<))B=%)P>D;30'.28G12<'A!4T!SD'!XQY(
MP>D"20G+3(M-H$T!P4T!T4R)V4PQZ4@QP4D!R42)\4F)RDG!ZAM-`=%)B<I)
MP>(%30'1P>`>2,'J`D@)T$R+5:A-`<)-`>I(B<),,=I,,?))`=)$B<I(B=-(
MP>L;20':2(G32,'C!4D!VD'!YAY(P>D"20G.2(M=N$P!PT@!PT0Q\$0QR$0#
M7;!!`<-$B=%(B<A(P>@;1`'818G30<'C!40!V`76P6+*0<'A'DC!Z@))"=%,
MB<I,,?),,=)(`=-(B<)(P>H;2`'32(G"2,'B!4@!TT'!XAY(P>D"20G*08G;
M3`-%P$T!\$R)T4PQR4@QP4D!R(G9P>$%20'(3(G92,'I&TD!R(G!P>$>2,'H
M`@G(10'A2(N50/W__P'"1#'0,=A!`<%$B<!(P>@;1`'(2(N-./W__T0!P4'!
MX`5$`<`%UL%BRDB)!TB)3PC!XQX!WDG!ZP)$`=Y(B7<02(E7&$B+A4C]__]$
M`=!(B4<@2(L%/"H``$@[1=!U$DB!Q*@"``!;05Q!74%>05]=P^A_`@``9F9F
M9F9F+@\?A```````54B)Y4%7059!54%44U!(B?-)B?Y(BU8H3(MN,$F)U,'J
M`X/B/XU"`<9$%CB`2(T\!DB#QSB#^CAR,4R->SB#\C\Q]NA(!0``2(G?Z(#I
M__\/5\!!#Q%'($$/$4<000\1!TG'1S``````ZQ&X-P```"G0,?9(B<+H%`4`
M`$R)Z4R)Z$C!Z!B(0W!,B>A(P>@0B$-QB&MRB$MS3(GA3(G@2,'H&(A#=$R)
MX$C!Z!"(0W6(:W:(2W=(B=_H$NG__P^V0P-!B`8/MD,"08A&`0^V0P%!B$8"
M#[8#08A&`P^V0PM!B$8$#[9#"D&(1@4/MD,)08A&!@^V0PA!B$8'#[9#$T&(
M1@@/MD,208A&"0^V0Q%!B$8*#[9#$$&(1@L/MD,;08A&#`^V0QI!B$8-#[9#
M&4&(1@X/MD,808A&#P^V0R-!B$80#[9#(D&(1A$/MD,A08A&$@^V0R!!B$83
M2(G?2(/$"%M!7$%=05Y!7UWI?@(``,S,S,S,S,S,S,S,S,S,54B)Y5-02(T=
M$Q0```\?`$B+`TB-2`%(@_D"<@C_T$B#P_CKZTB#Q`A;7<-52(GEZ,O___]=
MPP!52(GEZ.^]__]=PP````````````````#_-0HF``#_)0PF```/'T``_R4*
M)@``:`````#IX/____\E`B8``&@!````Z=#_____)?HE``!H`@```.G`____
M_R7R)0``:`,```#IL/____\EZB4``&@$````Z:#_____)>(E``!H!0```.F0
M_____R7:)0``:`8```#I@/____\ETB4``&@'````Z7#_____)<HE``!H"```
M`.E@_____R7")0``:`D```#I4/____\ENB4``&@*````Z4#_____);(E``!H
M"P```.DP_____R6J)0``:`P```#I(/____\EHB4``&@-````Z1#_____)9HE
M``!H#@```.D`_____R62)0``:`\```#I\/[___\EBB4``&@0````Z>#^____
M)8(E``!H$0```.G0_O___R5Z)0``:!(```#IP/[___\E<B4``&@3````Z;#^
M____)6HE``!H%````.F@_O___R5B)0``:!4```#ID/[___\E6B4``&@6````
MZ8#^____)5(E``!H%P```.EP_O___R5*)0``:!@```#I8/[___\E0B4``&@9
M````Z5#^____)3HE``!H&@```.E`_O___R4R)0``:!L```#I,/[___\E*B4`
M`&@<````Z2#^____)2(E``!H'0```.D0_O___R4:)0``:!X```#I`/[___\E
M$B4``&@?````Z?#]____)0HE``!H(````.G@_?___R4")0``:"$```#IT/W_
M__\E^B0``&@B````Z<#]____)?(D``!H(P```.FP_?___R7J)```:"0```#I
MH/W___\EXB0``&@E````Z9#]____)=HD``!H)@```.F`_?___R72)```:"<`
M``#I</W___\ERB0``&@H````Z6#]____)<(D``!H*0```.E0_?___R6Z)```
M:"H```#I0/W___\ELB0``&@K````Z3#]____):HD``!H+````.D@_?___R6B
M)```:"T```#I$/W___\EFB0``&@N````Z0#]____)9(D``!H+P```.GP_/__
M_R6*)```:#````#IX/S___\E@B0``&@Q````Z=#\____)7HD``!H,@```.G`
M_/___R5R)```:#,```#IL/S___\E:B0``&@T````Z:#\____)6(D``!H-0``
M`.F0_/___R5:)```:#8```#I@/S___\E4B0``&@W````Z7#\____)4HD``!H
M.````.E@_/___R5")```:#D```#I4/S___\E.B0``&@Z````Z4#\____)3(D
M``!H.P```.DP_/____________\``````````/__________````````````
M`````````/!P(```````'0````````#V`P````````$`````````&@0`````
M```!`````````"H$`````````0`````````U!`````````$`````````/P0`
M```````!`````````$T$`````````0````````#%`P````````$`````````
MV@,````````5````````````````````!P````````"(%"````````@`````
M````8``````````)`````````!@`````````%P````````#H%"````````(`
M````````H`4````````#`````````.C8(```````%``````````'````````
M``8`````````"`,@```````+`````````!@`````````!0`````````L$"``
M``````H`````````6@0```````#U_O]O`````'@,(```````!`````````!<
M#2```````!D`````````V,8@```````;``````````@`````````#```````
M``"\LB````````T`````````R+(@``````#P__]O`````&`+(```````_O__
M;P`````4#"```````/___V\``````@``````````````````````````````
M``````````!H&R```````#D<(```````"E!!4BYP;0H``````````.#&(```
M`````````````````````````/:R(```````!K,@```````6LR```````":S
M(```````-K,@``````!&LR```````%:S(```````9K,@``````!VLR``````
M`(:S(```````EK,@``````"FLR```````+:S(```````QK,@``````#6LR``
M`````.:S(```````]K,@```````&M"```````!:T(```````)K0@```````V
MM"```````$:T(```````5K0@``````!FM"```````':T(```````AK0@````
M``"6M"```````*:T(```````MK0@``````#&M"```````-:T(```````YK0@
M``````#VM"````````:U(```````%K4@```````FM2```````#:U(```````
M1K4@``````!6M2```````&:U(```````=K4@``````"&M2```````):U(```
M````IK4@``````"VM2```````,:U(```````UK4@``````#FM2```````/:U
M(```````!K8@```````6MB```````":V(```````-K8@``````!&MB``````
M`%:V(```````9K8@``````!VMB```````(:V(```````EK8@``````"FMB``
M`````$QI;FME<CH@3$Q$(#$V+C`N-B`H1G)E94)31"!L;'9M;W)G+3$V+C`N
M-BTP+6<W8V)F,6$R-3DQ-3(M,30P,#`P-BD``$9R965"4T0@8VQA;F<@=F5R
M<VEO;B`Q-BXP+C8@*&AT='!S.B\O9VET:'5B+F-O;2]L;'9M+VQL=FTM<')O
M:F5C="YG:70@;&QV;6]R9RTQ-BXP+C8M,"UG-V-B9C%A,C4Y,34R*0``+FEN
M=&5R<``N;F]T92YT86<`+F1Y;G-Y;0`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+F=N=2YH87-H`"YH87-H`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA
M+G!L=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YT97AT`"YI
M;FET`"YF:6YI`"YP;'0`+F-T;W)S`"YD=&]R<P`N:F-R`"YI;FET7V%R<F%Y
M`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F=O="YP;'0`+F)S<P`N8V]M;65N=``N
M<VAS=')T86(`````````````````````````````````````````````````
M``````````````````````````````````````````````$````!`````@``
M``````"H`B```````*@"````````%0````````````````````$`````````
M```````````)````!P````(`````````P`(@``````#``@```````$@`````
M```````````````$````````````````````$P````L````"``````````@#
M(```````"`,```````!8"`````````@````!````"``````````8````````
M`!L```#___]O`@````````!@"R```````&`+````````L@`````````#````
M``````(``````````@`````````H````_O__;P(`````````%`P@```````4
M#````````&``````````"`````(````$````````````````````-P```/;_
M_V\"`````````'@,(```````>`P```````#D``````````,`````````"```
M`````````````````$$````%`````@````````!<#2```````%P-````````
MT`(````````#``````````0`````````!`````````!'`````P````(`````
M````+!`@```````L$````````%H$```````````````````!````````````
M````````3P````0````"`````````(@4(```````B!0```````!@````````
M``,`````````"``````````8`````````%D````$````0@````````#H%"``
M`````.@4````````H`4````````#````&0````@`````````&`````````!C
M`````0```#(`````````D!H@``````"0&@```````+=`````````````````
M```0````````````````````:P````$````"`````````$A;(```````2%L`
M``````#<````````````````````!````````````````````'D````!````
M`@`````````H7"```````"A<````````3`0```````````````````@`````
M``````````````"#`````0````8`````````@'`@``````"`8````````#Q"
M```````````````````0````````````````````B0````$````&````````
M`+RR(```````O*(````````+````````````````````!```````````````
M`````(\````!````!@````````#(LB```````,BB````````"P``````````
M``````````0```````````````````"5`````0````8`````````X+(@````
M``#@H@```````-`#```````````````````0````````````````````F@``
M``$````#`````````+#&(```````L*8````````0````````````````````
M"````````````````````*$````!`````P````````#`QB```````,"F````
M````$`````````````````````@```````````````````"H`````0````,`
M````````T,8@``````#0I@````````@````````````````````(````````
M````````````K0````X````#`````````-C&(```````V*8````````(````
M````````````````"````````````````````+D````&`````P````````#@
MQB```````."F````````X`$````````(``````````@`````````$```````
M``#"`````0````,`````````P,@@``````#`J`````````@`````````````
M```````(````````````````````QP````$````#`````````,C8(```````
MR*@````````9````````````````````"````````````````````,T````!
M`````P````````#HV"```````.BH````````^`$```````````````````@`
M``````````````````#6````"`````,`````````X-H@``````#@J@``````
M`)$````````````````````@````````````````````VP````$````P````
M````````````````X*H```````"L`````````````````````0`````````!
M`````````.0````#`````````````````````````(RK````````[@``````
:``````````````$`````````````````````
